@@ -1,6 +1,6 @@
 ﻿#  -*- coding: utf-8 -*-
 #   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
+#   Copyright (C) 2020-2021  John Mille <john@compose-x.io>
 #  #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -32,10 +32,6 @@ from troposphere.servicediscovery import (
 from ecs_composex.appmesh import appmesh_conditions
 from ecs_composex.appmesh.appmesh_params import NODE_KEY, ROUTER_KEY, ROUTERS_KEY
 from ecs_composex.common import NONALPHANUM, keyisset
-from ecs_composex.dns.dns_params import (
-    PRIVATE_DNS_ZONE_ID,
-    PRIVATE_DNS_ZONE_NAME,
-)
 
 
 def validate_service_backend(service, routers, nodes):
