@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #  ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#  Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
+#  Copyright (C) 2020-2021  John Mille <john@compose-x.io>
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -28,12 +28,11 @@ from troposphere import (
     AWSObject,
     AWSHelperFn,
     AWS_STACK_NAME,
-    Parameter,
 )
 
 from ecs_composex.common import LOG
 from ecs_composex.common.cfn_conditions import USE_STACK_NAME_CON_T
-from ecs_composex.common.cfn_params import ROOT_STACK_NAME_T
+from ecs_composex.common.cfn_params import ROOT_STACK_NAME_T, Parameter
 from ecs_composex.common.ecs_composex import CFN_EXPORT_DELIMITER
 
 
