@@ -1,6 +1,6 @@
-﻿#  -*- coding: utf-8 -*-
+#  -*- coding: utf-8 -*-
 #   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
+#   Copyright (C) 2020-2021  John Mille <john@compose-x.io>
 #  #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -19,9 +19,9 @@
 Module for the ComposeXSettings class
 """
 
-from re import sub
 from copy import deepcopy
 from datetime import datetime as dt
+from re import sub
 
 import boto3
 import yaml
@@ -29,29 +29,23 @@ from botocore.exceptions import ClientError
 from cfn_flip.yaml_dumper import LongCleanDumper
 
 from ecs_composex import __version__
-from ecs_composex.ingress_settings import set_service_ports
 from ecs_composex.common import keyisset, LOG, load_composex_file, NONALPHANUM
 from ecs_composex.common.aws import get_account_id, get_region_azs
 from ecs_composex.common.aws import get_cross_role_session
 from ecs_composex.common.cfn_params import USE_FLEET_T
-from ecs_composex.secrets.compose_secrets import ComposeSecret
+from ecs_composex.common.compose_networks import ComposeNetwork
 from ecs_composex.common.compose_services import (
     ComposeService,
     ComposeFamily,
 )
 from ecs_composex.common.compose_volumes import ComposeVolume
-from ecs_composex.common.compose_networks import ComposeNetwork
 from ecs_composex.common.envsubst import expandvars
 from ecs_composex.iam import ROLE_ARN_ARG
 from ecs_composex.iam import validate_iam_role_arn
+from ecs_composex.ingress_settings import set_service_ports
+from ecs_composex.secrets.compose_secrets import ComposeSecret
 from ecs_composex.utils.init_ecs import set_ecs_settings
 from ecs_composex.utils.init_s3 import create_bucket
-from ecs_composex.vpc.vpc_params import (
-    VPC_ID,
-    APP_SUBNETS,
-    PUBLIC_SUBNETS,
-    STORAGE_SUBNETS,
-)
 
 
 def render_services_ports(services):
@@ -406,6 +400,7 @@ class ComposeXSettings(object):
         self.services = []
         self.secrets = []
         self.networks = []
+        self.vpc_imported = False
         self.subnets_parameters = []
         self.subnets_mappings = {}
         self.secrets_mappings = {}
@@ -416,6 +411,7 @@ class ComposeXSettings(object):
         self.format = self.default_format
 
         self.create_vpc = False
+        self.requires_private_namespace = False
         self.vpc_cidr = None
         self.single_nat = None
         self.lookup_vpc = False
@@ -432,9 +428,23 @@ class ComposeXSettings(object):
         self.set_content(kwargs, content)
         self.set_output_settings(kwargs)
         self.use_appmesh = keyisset("x-appmesh", self.compose_content)
+        self.evaluate_private_namespace()
         self.name = kwargs[self.name_arg]
         self.ecs_cluster = None
 
+    def evaluate_private_namespace(self):
+        """
+        Method to go over all services and figure out if any of them requires cloudmap.
+        If so it will also expect x-dns.PrivateNamespace to be set.
+        """
+        self.requires_private_namespace = self.use_appmesh or any(
+            keyisset("UseCloudmap", service.x_network) for service in self.services
+        )
+        if self.requires_private_namespace:
+            LOG.warning(
+                "At least one service requires cloudmap or AppMesh is used. Enabling private namespace"
+            )
+
     def set_secrets(self):
         """
         Function to parse the settings compose content and define the secrets.
@@ -454,6 +464,47 @@ class ComposeXSettings(object):
                 self.secrets.append(secret)
                 self.compose_content[ComposeSecret.main_key][secret_name] = secret
 
+    def set_efs(self):
+        """
+        Method to add a x-efs definition to the compose-x definition when a volume is flagged as using NFS/EFS
+        """
+        if (
+            not self.volumes
+            or not keyisset(ComposeVolume.main_key, self.compose_content)
+            or not self.compose_content[ComposeVolume.main_key]
+        ):
+            return
+        if not keyisset("x-efs", self.compose_content):
+            efs = {}
+            self.compose_content["x-efs"] = efs
+        else:
+            efs = self.compose_content["x-efs"]
+        for volume in self.compose_content[ComposeVolume.main_key].values():
+            if volume.lookup or volume.use:
+                continue
+            if (
+                volume.efs_definition
+                or volume.driver == "nfs"
+                or volume.driver == "efs"
+            ):
+                if not keyisset(volume.name, efs):
+                    efs[volume.name] = {
+                        "Properties": volume.efs_definition,
+                        "MacroParameters": volume.parameters,
+                        "Lookup": volume.lookup,
+                        "Use": volume.use,
+                        "Services": [
+                            {"name": service.name, "access": "RW"}
+                            for service in volume.services
+                        ],
+                        "Settings": {"Subnets": "StorageSubnets"},
+                        "Volume": volume,
+                    }
+                else:
+                    LOG.warning(
+                        f"x-efs {volume.name} was already defined in top-level x-efs. Not overriding from volumes"
+                    )
+
     def set_volumes(self):
         """
         Method configuring the volumes at root level
@@ -593,6 +644,7 @@ class ComposeXSettings(object):
             self.set_volumes()
             self.set_services()
             self.set_families()
+            self.set_efs()
 
     def parse_command(self, kwargs, content=None):
         """
@@ -688,15 +740,10 @@ class ComposeXSettings(object):
             else:
                 LOG.error(error)
 
-    def set_azs_from_vpc_import(
-        self, public_subnets, app_subnets, storage_subnets, session=None
-    ):
+    def set_azs_from_vpc_import(self, subnets, session=None):
         """
         Function to get the list of AZs for a given set of subnets
-
-        :param list public_subnets:
-        :param list app_subnets:
-        :param list storage_subnets:
+        :param dict subnets:
         :param session: The Session used to find the EC2 subnets (useful for lookup).
         :return:
         """
@@ -704,19 +751,19 @@ class ComposeXSettings(object):
             client = self.session.client("ec2")
         else:
             client = session.client("ec2")
-        try:
-            public_r = client.describe_subnets(SubnetIds=public_subnets)["Subnets"]
-            app_r = client.describe_subnets(SubnetIds=app_subnets)["Subnets"]
-            storage_r = client.describe_subnets(SubnetIds=storage_subnets)["Subnets"]
-            self.public_azs = [sub["AvailabilityZone"] for sub in public_r]
-            self.subnets_mappings[PUBLIC_SUBNETS.title]["Azs"] = self.public_azs
-            self.storage_azs = [sub["AvailabilityZone"] for sub in storage_r]
-            self.subnets_mappings[STORAGE_SUBNETS.title]["Azs"] = self.storage_azs
-            self.app_azs = [sub["AvailabilityZone"] for sub in app_r]
-            self.subnets_mappings[APP_SUBNETS.title]["Azs"] = self.app_azs
-            LOG.info("Successfully updated self with AZs from looked up VPC subnets")
-        except ClientError:
-            LOG.warning("Could not define the AZs based on the imported subnets")
+        for subnet_name, subnet_definition in subnets.items():
+            if not isinstance(subnet_definition, list):
+                continue
+            try:
+                subnets_r = client.describe_subnets(SubnetIds=subnet_definition)[
+                    "Subnets"
+                ]
+                self.subnets_mappings[subnet_name]["Azs"] = [
+                    subnet["AvailabilityZone"] for subnet in subnets_r
+                ]
+            except ClientError:
+                LOG.warning("Could not define the AZs based on the imported subnets")
+        self.vpc_imported = True
 
     def set_bucket_name_from_account_id(self):
         if self.bucket_name and isinstance(self.bucket_name, str):
