@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #  ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#  Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
+#  Copyright (C) 2020-2021  John Mille <john@compose-x.io>
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -37,11 +37,12 @@ otherwise you could not, i.e., *vpc::usage::ecsapps*
 
 import copy
 
-from troposphere import Tags, Parameter, Ref
+from troposphere import Tags, Ref
 from troposphere.ec2 import LaunchTemplate, TagSpecifications
 from troposphere.ssm import Parameter as SSMParameter
 
 from ecs_composex.common import keyisset, NONALPHANUM, LOG, add_parameters
+from ecs_composex.common.cfn_params import Parameter
 from ecs_composex.common.stacks import ComposeXStack
 
 
