@@ -1,6 +1,6 @@
 ﻿#  -*- coding: utf-8 -*-
 #   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
+#   Copyright (C) 2020-2021  John Mille <john@compose-x.io>
 #  #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@ Module to link DocDB cluster to ECS Services.
 
 from ecs_composex.common import keyisset
 from ecs_composex.common import LOG
-from ecs_composex.docdb.docdb_params import DOCDB_PORT
 from ecs_composex.tcp_resources_settings import handle_new_tcp_resource
 from ecs_composex.rds.rds_ecs import (
     import_dbs,
@@ -29,6 +28,7 @@ from ecs_composex.rds.rds_ecs import (
     validate_rds_lookup,
     DB_SECRET_T,
 )
+from ecs_composex.docdb.docdb_params import DOCDB_SG, DOCDB_SECRET, DOCDB_PORT
 
 
 def create_docdb_cluster_config_mapping(resource, db_config):
@@ -91,7 +91,13 @@ def docdb_to_ecs(resources, services_stack, res_root_stack, settings):
         resources[res_name] for res_name in resources if resources[res_name].lookup
     ]
     for new_res in new_resources:
-        handle_new_tcp_resource(new_res, res_root_stack, DOCDB_PORT)
+        handle_new_tcp_resource(
+            new_res,
+            res_root_stack,
+            port_parameter=DOCDB_PORT,
+            sg_parameter=DOCDB_SG,
+            secret_parameter=DOCDB_SECRET,
+        )
     create_lookup_mappings(db_mappings, lookup_resources, settings)
     for lookup_res in lookup_resources:
         if keyisset(lookup_res.logical_name, db_mappings):
