@@ -1,6 +1,6 @@
 ﻿#  -*- coding: utf-8 -*-
 #   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
+#   Copyright (C) 2020-2021  John Mille <john@compose-x.io>
 #  #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -17,10 +17,12 @@
 
 from os import path
 
-from troposphere import Parameter
+from ecs_composex.ecs_composex import X_KEY
+from ecs_composex.common.cfn_params import Parameter
 from ecs_composex.vpc.vpc_params import SG_ID_TYPE
 
-RES_KEY = f"x-{path.basename(path.dirname(path.abspath(__file__)))}"
+MOD_KEY = path.basename(path.dirname(path.abspath(__file__)))
+RES_KEY = f"{X_KEY}{MOD_KEY}"
 
 
 DOCDB_NAME_T = "DocDBName"
@@ -33,9 +35,17 @@ DOCDB_SECRET_T = "DocDbSecret"
 DOCDB_SUBNET_GROUP_T = "DocDbSubnetGroup"
 
 DOCDB_NAME = Parameter(DOCDB_NAME_T, Type="String")
-DOCDB_ID_T = Parameter(DOCDB_ID_T, Type="String")
-DOCDBC_ENDPOINT = Parameter(DOCDB_ENDPOINT_T, Type="String")
-DOCDBC_READ_ENDPOINT = Parameter(DOCDB_READ_ENDPOINT_T, Type="String")
-DOCDB_PORT = Parameter(DOCDB_PORT_T, Type="Number", MinValue=1, MaxValue=((2 ^ 16) - 1))
-DOCDB_SG = Parameter(DOCDB_SG_T, Type=SG_ID_TYPE)
+DOCDB_ID_T = Parameter(DOCDB_ID_T, return_value="ClusterResourceId", Type="String")
+DOCDBC_ENDPOINT = Parameter(DOCDB_ENDPOINT_T, return_value="Endpoint", Type="String")
+DOCDBC_READ_ENDPOINT = Parameter(
+    DOCDB_READ_ENDPOINT_T, return_value="ReadEndpoint", Type="String"
+)
+DOCDB_PORT = Parameter(
+    DOCDB_PORT_T,
+    return_value="Port",
+    Type="Number",
+    MinValue=1,
+    MaxValue=((2 ^ 16) - 1),
+)
+DOCDB_SG = Parameter(DOCDB_SG_T, return_value="GroupId", Type=SG_ID_TYPE)
 DOCDB_SECRET = Parameter(DOCDB_SECRET_T, Type="String")
