@@ -1,6 +1,6 @@
 ﻿#  -*- coding: utf-8 -*-
 #   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
+#   Copyright (C) 2020-2021  John Mille <john@compose-x.io>
 #  #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -17,13 +17,15 @@
 
 from os import path
 from ecs_composex.ecs_composex import X_KEY
-from troposphere import Parameter
+from ecs_composex.common.cfn_params import Parameter
 
-TABLE_NAME_T = "DynamoDbTableName"
+TABLE_NAME_T = "TableName"
 TABLE_NAME = Parameter(TABLE_NAME_T, Type="String", AllowedPattern=r"[a-zA-Z0-9_.-]+")
 
 TABLE_ARN_T = "Arn"
-TABLE_ARN = Parameter(TABLE_ARN_T, Type="String")
+TABLE_ARN = Parameter(TABLE_ARN_T, return_value="Arn", Type="String")
+
+MOD_KEY = path.basename(path.dirname(path.abspath(__file__)))
+RES_KEY = f"{X_KEY}{MOD_KEY}"
 
-RES_KEY = f"{X_KEY}{path.basename(path.dirname(path.abspath(__file__)))}"
 TABLE_SSM_PREFIX = f"/{RES_KEY}/"
