@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #  ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#  Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
+#  Copyright (C) 2020-2021  John Mille <john@compose-x.io>
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -24,9 +24,9 @@ which it heavily relies onto.
 You can change the names *values* so you like so long as you keep it [a-zA-Z0-9]
 """
 
-from troposphere import Parameter, Select, Split, Ref, ImportValue, Sub
+from troposphere import Select, Split, Ref, ImportValue, Sub
 from ecs_composex.common.ecs_composex import CFN_EXPORT_DELIMITER as delim
-from ecs_composex.common.cfn_params import ROOT_STACK_NAME_T
+from ecs_composex.common.cfn_params import ROOT_STACK_NAME_T, Parameter
 from ecs_composex.vpc.vpc_params import SG_ID_TYPE
 
 CLUSTER_T = "EcsCluster"
