@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #  ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#  Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
+#  Copyright (C) 2020-2021  John Mille <john@compose-x.io>
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -36,6 +36,8 @@ from troposphere.ecs import (
     AwsvpcConfiguration,
     NetworkConfiguration,
     DeploymentController,
+    DeploymentConfiguration,
+    DeploymentCircuitBreaker,
 )
 from troposphere.ecs import ServiceRegistry
 from troposphere.elasticloadbalancingv2 import (
@@ -52,17 +54,12 @@ from ecs_composex.common import keyisset, LOG
 from ecs_composex.common.cfn_conditions import USE_STACK_NAME_CON_T
 from ecs_composex.common.cfn_params import ROOT_STACK_NAME_T
 from ecs_composex.common.outputs import ComposeXOutput
-from ecs_composex.dns.dns_params import (
-    PRIVATE_DNS_ZONE_NAME,
-    PRIVATE_DNS_ZONE_ID,
-    PUBLIC_DNS_ZONE_ID,
-    PUBLIC_DNS_ZONE_NAME,
-    PRIVATE_NAMESPACE_ID,
-)
 from ecs_composex.dns.dns_conditions import (
-    PRIVATE_ZONE_ID_CON_T,
     PRIVATE_NAMESPACE_CON_T,
 )
+from ecs_composex.dns.dns_params import (
+    PRIVATE_NAMESPACE_ID,
+)
 from ecs_composex.ecs import ecs_params, ecs_conditions
 from ecs_composex.ecs.ecs_conditions import USE_HOSTNAME_CON_T
 from ecs_composex.ecs.ecs_params import SERVICE_NAME, SERVICE_HOSTNAME
@@ -224,6 +221,8 @@ def create_scalable_target(family):
     Method to automatically create a scalable target
     """
     LOG.debug(family.service_config.scaling.scaling_range)
+    if ecs_params.SERVICE_SCALING_TARGET in family.template.resources:
+        return
     if family.service_config.scaling.scaling_range:
         family.scalable_target = applicationautoscaling.ScalableTarget(
             ecs_params.SERVICE_SCALING_TARGET,
@@ -244,6 +243,26 @@ def create_scalable_target(family):
                 DynamicScalingInSuspended=False
             ),
         )
+    else:
+        family.scalable_target = applicationautoscaling.ScalableTarget(
+            ecs_params.SERVICE_SCALING_TARGET,
+            template=family.template,
+            MaxCapacity=family.service_config.replicas,
+            MinCapacity=family.service_config.replicas,
+            ScalableDimension="ecs:service:DesiredCount",
+            ServiceNamespace="ecs",
+            RoleARN=Sub(
+                "arn:${AWS::Partition}:iam::${AWS::AccountId}:role/"
+                "ecs.application-autoscaling.${AWS::URLSuffix}/"
+                "AWSServiceRoleForApplicationAutoScaling_ECSService"
+            ),
+            ResourceId=Sub(
+                f"service/${{{ecs_params.CLUSTER_NAME.title}}}/${{{family.service_definition.title}.Name}}"
+            ),
+            SuspendedState=applicationautoscaling.SuspendedState(
+                DynamicScalingInSuspended=False
+            ),
+        )
     if family.scalable_target and family.service_config.scaling.target_scaling:
         if keyisset("CpuTarget", family.service_config.scaling.target_scaling):
             applicationautoscaling.ScalingPolicy(
@@ -288,6 +307,11 @@ def generate_service_template_outputs(family):
                     vpc_params.APP_SUBNETS.title,
                     Join(",", Ref(vpc_params.APP_SUBNETS)),
                 ),
+                (
+                    family.scalable_target.title,
+                    ecs_params.SERVICE_SCALING_TARGET,
+                    Ref(family.scalable_target),
+                ),
             ],
             duplicate_attr=False,
             export=False,
@@ -313,6 +337,32 @@ def define_service_ingress(family, settings):
     return service_attrs
 
 
+def define_deployment_options(family, settings, kwargs):
+    """
+    Function to define the DeploymentConfiguration
+
+    :param ecs_composex.common.compose_services.ComposeFamily family:
+    :param ecs_composex.common.settings.ComposeXSettings settings:
+    :param dict kwargs:
+    :return:
+    """
+    family.set_service_update_config()
+    default = DeploymentConfiguration(
+        DeploymentCircuitBreaker=DeploymentCircuitBreaker(Enable=True, RollBack=True),
+    )
+    if family.deployment_config:
+        deploy_config = DeploymentConfiguration(
+            MaximumPercent=family.deployment_config["MaximumPercent"],
+            MinimumHealthyPercent=family.deployment_config["MinimumHealthyPercent"],
+            DeploymentCircuitBreaker=DeploymentCircuitBreaker(
+                Enable=True, RollBack=keyisset("RollBack", family.deployment_config)
+            ),
+        )
+        kwargs.update({"DeploymentConfiguration": deploy_config})
+    else:
+        kwargs.update({"DeploymentConfiguration": default})
+
+
 class Service(object):
     """
     Class representing the service from the Docker compose file and translate it into
@@ -360,6 +410,7 @@ class Service(object):
         ]
         service_sgs += [sg for sg in self.sgs if isinstance(sg, (Ref, Sub, If, GetAtt))]
         attrs = define_service_ingress(family, settings)
+        define_deployment_options(family, settings, attrs)
         self.ecs_service = EcsService(
             ecs_params.SERVICE_T,
             template=family.template,
