@@ -1,6 +1,6 @@
 ﻿#  -*- coding: utf-8 -*-
 #   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
+#   Copyright (C) 2020-2021  John Mille <john@compose-x.io>
 #  #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -20,13 +20,14 @@ Module to handle the AWS ES Stack and resources creation
 """
 
 import json
+
 from troposphere import Ref, GetAtt, Sub
-from troposphere.ssm import Parameter
+from troposphere.ssm import Parameter as SSMParameter
 
 from ecs_composex.common.compose_resources import XResource, set_resources
 from ecs_composex.common.stacks import ComposeXStack
-from ecs_composex.vpc.vpc_params import STORAGE_SUBNETS
 from ecs_composex.elasticache.elasticache_params import (
+    MOD_KEY,
     RES_KEY,
     CLUSTER_NAME,
     CLUSTER_MEMCACHED_ADDRESS,
@@ -37,8 +38,11 @@ from ecs_composex.elasticache.elasticache_params import (
     REPLICA_READ_ENDPOINT_PORTS,
     REPLICA_PRIMARY_ADDRESS,
     REPLICA_PRIMARY_PORT,
+    CLUSTER_SG,
+    CLUSTER_CONFIG,
 )
 from ecs_composex.elasticache.elasticache_template import create_root_template
+from ecs_composex.vpc.vpc_params import STORAGE_SUBNETS
 
 
 class CacheCluster(XResource):
@@ -48,7 +52,7 @@ class CacheCluster(XResource):
 
     subnets_param = STORAGE_SUBNETS
 
-    def __init__(self, name, definition, settings):
+    def __init__(self, name, definition, module_name, settings):
         self.db_sg = None
         self.parameter_group = None
         self.db_secret = None
@@ -56,7 +60,7 @@ class CacheCluster(XResource):
         self.engine = None
         self.port_attr = None
         self.config_parameter = None
-        super().__init__(name, definition, settings)
+        super().__init__(name, definition, module_name, settings)
         self.set_override_subnets()
 
     def init_memcached_outputs(self):
@@ -64,44 +68,39 @@ class CacheCluster(XResource):
         Method to init the DocDB output attributes
         """
         self.output_properties = {
-            CLUSTER_NAME.title: (self.logical_name, self.cfn_resource, Ref, None),
-            CLUSTER_MEMCACHED_PORT.title: (
-                f"{self.logical_name}{CLUSTER_MEMCACHED_PORT.title}",
+            CLUSTER_NAME: (self.logical_name, self.cfn_resource, Ref, None),
+            CLUSTER_MEMCACHED_PORT: (
+                f"{self.logical_name}{CLUSTER_MEMCACHED_PORT.return_value}",
                 self.cfn_resource,
                 GetAtt,
-                CLUSTER_MEMCACHED_PORT.Description,
+                CLUSTER_MEMCACHED_PORT.return_value,
             ),
-            CLUSTER_MEMCACHED_ADDRESS.title: (
-                f"{self.logical_name}{CLUSTER_MEMCACHED_ADDRESS.title}",
+            CLUSTER_MEMCACHED_ADDRESS: (
+                f"{self.logical_name}{CLUSTER_MEMCACHED_ADDRESS.return_value}",
                 self.cfn_resource,
                 GetAtt,
-                CLUSTER_MEMCACHED_ADDRESS.Description,
-            ),
-            self.db_sg.title: (
-                self.db_sg.title,
-                self.db_sg,
-                GetAtt,
-                "GroupId",
+                CLUSTER_MEMCACHED_ADDRESS.return_value,
             ),
+            CLUSTER_SG: (self.db_sg.title, self.db_sg, GetAtt, CLUSTER_SG.return_value),
         }
 
     def add_memcahed_config(self, template):
         self.port_attr = CLUSTER_MEMCACHED_PORT
         if not self.lookup:
-            self.config_parameter = Parameter(
+            self.config_parameter = SSMParameter(
                 f"{self.logical_name}Config",
                 template=template,
                 Type="String",
                 Value=Sub(
                     json.dumps(
                         {
-                            "endpoint": f"${{{self.logical_name}.{CLUSTER_MEMCACHED_ADDRESS.Description}}}",
-                            "port": f"${{{self.logical_name}.{CLUSTER_MEMCACHED_PORT.Description}}}",
+                            "endpoint": f"${{{self.logical_name}.{CLUSTER_MEMCACHED_ADDRESS.return_value}}}",
+                            "port": f"${{{self.logical_name}.{CLUSTER_MEMCACHED_PORT.return_value}}}",
                         }
                     ),
                 ),
             )
-            self.output_properties["Config"] = (
+            self.output_properties[CLUSTER_CONFIG] = (
                 self.config_parameter.title,
                 self.config_parameter,
                 Ref,
@@ -110,60 +109,55 @@ class CacheCluster(XResource):
 
     def init_redis_replica_outputs(self):
         self.output_properties = {
-            CLUSTER_NAME.title: (self.logical_name, self.cfn_resource, Ref, None),
-            REPLICA_PRIMARY_PORT.title: (
+            CLUSTER_NAME: (self.logical_name, self.cfn_resource, Ref, None),
+            REPLICA_PRIMARY_PORT: (
                 f"{self.logical_name}{REPLICA_PRIMARY_PORT.title}",
                 self.cfn_resource,
                 GetAtt,
-                REPLICA_PRIMARY_PORT.Description,
+                REPLICA_PRIMARY_PORT.return_value,
             ),
-            REPLICA_PRIMARY_ADDRESS.title: (
+            REPLICA_PRIMARY_ADDRESS: (
                 f"{self.logical_name}{REPLICA_PRIMARY_ADDRESS.title}",
                 self.cfn_resource,
                 GetAtt,
-                REPLICA_PRIMARY_ADDRESS.Description,
+                REPLICA_PRIMARY_ADDRESS.return_value,
             ),
-            REPLICA_READ_ENDPOINT_ADDRESSES.title: (
+            REPLICA_READ_ENDPOINT_ADDRESSES: (
                 f"{self.logical_name}{REPLICA_READ_ENDPOINT_ADDRESSES.title}",
                 self.cfn_resource,
                 GetAtt,
-                REPLICA_READ_ENDPOINT_ADDRESSES.Description,
+                REPLICA_READ_ENDPOINT_ADDRESSES.return_value,
             ),
-            REPLICA_READ_ENDPOINT_PORTS.title: (
+            REPLICA_READ_ENDPOINT_PORTS: (
                 f"{self.logical_name}{REPLICA_READ_ENDPOINT_PORTS.title}",
                 self.cfn_resource,
                 GetAtt,
-                REPLICA_READ_ENDPOINT_PORTS.Description,
-            ),
-            self.db_sg.title: (
-                self.db_sg.title,
-                self.db_sg,
-                GetAtt,
-                "GroupId",
+                REPLICA_READ_ENDPOINT_PORTS.return_value,
             ),
+            CLUSTER_SG: (self.db_sg.title, self.db_sg, GetAtt, CLUSTER_SG.return_value),
         }
         self.port_attr = REPLICA_PRIMARY_PORT
 
     def add_redis_replica_config(self, template):
         if not self.lookup:
-            self.config_parameter = Parameter(
+            self.config_parameter = SSMParameter(
                 f"{self.logical_name}Config",
                 template=template,
                 Type="String",
                 Value=Sub(
                     json.dumps(
                         {
-                            "endpoint": f"${{{self.logical_name}.{REPLICA_PRIMARY_ADDRESS.Description}}}",
-                            "port": f"${{{self.logical_name}.{REPLICA_PRIMARY_PORT.Description}}}",
-                            "readendpoints": f"{{{self.logical_name}{REPLICA_READ_ENDPOINT_ADDRESSES.Description}}}",
-                            "readports": f"{{{self.logical_name}{REPLICA_READ_ENDPOINT_PORTS.Description}}}",
-                            "url": f"redis://${{{self.logical_name}.{REPLICA_PRIMARY_ADDRESS.Description}}}:"
-                            f"${{{self.logical_name}.{REPLICA_PRIMARY_PORT.Description}}}",
+                            "endpoint": f"${{{self.logical_name}.{REPLICA_PRIMARY_ADDRESS.return_value}}}",
+                            "port": f"${{{self.logical_name}.{REPLICA_PRIMARY_PORT.return_value}}}",
+                            "readendpoints": f"{{{self.logical_name}{REPLICA_READ_ENDPOINT_ADDRESSES.return_value}}}",
+                            "readports": f"{{{self.logical_name}{REPLICA_READ_ENDPOINT_PORTS.return_value}}}",
+                            "url": f"redis://${{{self.logical_name}.{REPLICA_PRIMARY_ADDRESS.return_value}}}:"
+                            f"${{{self.logical_name}.{REPLICA_PRIMARY_PORT.return_value}}}",
                         }
                     ),
                 ),
             )
-            self.output_properties["Config"] = (
+            self.output_properties[CLUSTER_CONFIG] = (
                 self.config_parameter.title,
                 self.config_parameter,
                 Ref,
@@ -172,46 +166,41 @@ class CacheCluster(XResource):
 
     def init_redis_outputs(self):
         self.output_properties = {
-            CLUSTER_NAME.title: (self.logical_name, self.cfn_resource, Ref, None),
-            CLUSTER_REDIS_PORT.title: (
-                f"{self.logical_name}{CLUSTER_REDIS_PORT.title}",
+            CLUSTER_NAME: (self.logical_name, self.cfn_resource, Ref, None),
+            CLUSTER_REDIS_PORT: (
+                f"{self.logical_name}{CLUSTER_REDIS_PORT.return_value}",
                 self.cfn_resource,
                 GetAtt,
-                CLUSTER_REDIS_PORT.Description,
+                CLUSTER_REDIS_PORT.return_value,
             ),
-            CLUSTER_REDIS_ADDRESS.title: (
+            CLUSTER_REDIS_ADDRESS: (
                 f"{self.logical_name}{CLUSTER_REDIS_ADDRESS.title}",
                 self.cfn_resource,
                 GetAtt,
-                CLUSTER_REDIS_ADDRESS.Description,
-            ),
-            self.db_sg.title: (
-                self.db_sg.title,
-                self.db_sg,
-                GetAtt,
-                "GroupId",
+                CLUSTER_REDIS_ADDRESS.return_value,
             ),
+            CLUSTER_SG: (self.db_sg.title, self.db_sg, GetAtt, CLUSTER_SG.return_value),
         }
         self.port_attr = CLUSTER_REDIS_PORT
 
     def add_redis_config(self, template):
         if not self.lookup:
-            self.config_parameter = Parameter(
+            self.config_parameter = SSMParameter(
                 f"{self.logical_name}Config",
                 template=template,
                 Type="String",
                 Value=Sub(
                     json.dumps(
                         {
-                            "endpoint": f"${{{self.logical_name}.{CLUSTER_REDIS_ADDRESS.Description}}}",
-                            "port": f"${{{self.logical_name}.{CLUSTER_REDIS_PORT.Description}}}",
-                            "url": f"redis://${{{self.logical_name}.{CLUSTER_REDIS_ADDRESS.Description}}}:"
-                            f"${{{self.logical_name}.{CLUSTER_REDIS_PORT.Description}}}",
+                            "endpoint": f"${{{self.logical_name}.{CLUSTER_REDIS_ADDRESS.return_value}}}",
+                            "port": f"${{{self.logical_name}.{CLUSTER_REDIS_PORT.return_value}}}",
+                            "url": f"redis://${{{self.logical_name}.{CLUSTER_REDIS_ADDRESS.return_value}}}:"
+                            f"${{{self.logical_name}.{CLUSTER_REDIS_PORT.return_value}}}",
                         }
                     ),
                 ),
             )
-            self.output_properties["Config"] = (
+            self.output_properties[CLUSTER_CONFIG] = (
                 self.config_parameter.title,
                 self.config_parameter,
                 Ref,
@@ -225,14 +214,16 @@ class XStack(ComposeXStack):
     """
 
     def __init__(self, title, settings, **kwargs):
-        set_resources(settings, CacheCluster, RES_KEY)
+        set_resources(settings, CacheCluster, RES_KEY, MOD_KEY)
         new_resources = [
-            settings.compose_content[RES_KEY][res_name]
-            for res_name in settings.compose_content[RES_KEY]
-            if not settings.compose_content[RES_KEY][res_name].lookup
+            cache
+            for cache in settings.compose_content[RES_KEY].values()
+            if not cache.lookup and not cache.use
         ]
         if new_resources:
             stack_template = create_root_template(new_resources)
             super().__init__(title, stack_template, **kwargs)
         else:
             self.is_void = True
+        for resource in settings.compose_content[RES_KEY].values():
+            resource.stack = self
