@@ -1,6 +1,6 @@
 #  -*- coding: utf-8 -*-
 #   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
+#   Copyright (C) 2020-2021  John Mille <john@compose-x.io>
 #  #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -24,7 +24,7 @@ from copy import deepcopy
 from json import dumps
 
 from troposphere import AWS_STACK_NAME, AWS_NO_VALUE
-from troposphere import Ref, Sub, GetAtt, Select, Parameter, Tags, FindInMap
+from troposphere import Ref, Sub, GetAtt, Select, Tags, FindInMap
 from troposphere.ec2 import SecurityGroup, EIP
 from troposphere.elasticloadbalancingv2 import (
     LoadBalancer,
@@ -51,11 +51,12 @@ from ecs_composex.ingress_settings import Ingress, set_service_ports
 from ecs_composex.acm.acm_params import RES_KEY as ACM_KEY, MOD_KEY as ACM_MOD_KEY
 from ecs_composex.common import NONALPHANUM, LOG
 from ecs_composex.common import keyisset, keypresent, build_template, add_parameters
-from ecs_composex.common.cfn_params import ROOT_STACK_NAME
+from ecs_composex.common.cfn_params import ROOT_STACK_NAME, Parameter
 from ecs_composex.common.compose_resources import XResource, set_resources
 from ecs_composex.common.outputs import ComposeXOutput
 from ecs_composex.common.stacks import ComposeXStack
 from ecs_composex.elbv2.elbv2_params import (
+    MOD_KEY,
     RES_KEY,
     LB_SG_ID,
     LB_DNS_ZONE_ID,
@@ -682,7 +683,7 @@ class Elbv2(XResource):
 
     subnets_param = APP_SUBNETS
 
-    def __init__(self, name, definition, settings):
+    def __init__(self, name, definition, module_name, settings):
         if not keyisset("Listeners", definition):
             raise KeyError("You must specify at least one Listener for a LB.", name)
         self.lb_is_public = False
@@ -693,23 +694,23 @@ class Elbv2(XResource):
         self.unique_service_lb = False
         self.lb = None
         self.listeners = []
-        super().__init__(name, definition, settings)
+        super().__init__(name, definition, module_name, settings)
         self.validate_services()
         self.sort_props()
 
     def init_outputs(self):
         self.output_properties = {
-            LB_DNS_NAME.title: (
-                f"{self.logical_name}{LB_DNS_NAME.title}",
+            LB_DNS_NAME: (
+                f"{self.logical_name}{LB_DNS_NAME.return_value}",
                 self.cfn_resource,
                 GetAtt,
-                LB_DNS_NAME.title,
+                LB_DNS_NAME.return_value,
             ),
-            LB_DNS_ZONE_ID.title: (
-                f"{self.logical_name}{LB_DNS_ZONE_ID.title}",
+            LB_DNS_ZONE_ID: (
+                f"{self.logical_name}{LB_DNS_ZONE_ID.return_value}",
                 self.cfn_resource,
                 GetAtt,
-                LB_DNS_ZONE_ID.title,
+                LB_DNS_ZONE_ID.return_value,
             ),
         }
 
@@ -843,7 +844,7 @@ class Elbv2(XResource):
                 Tags=Tags(Name=Sub(f"elbv2-{self.logical_name}-${{{AWS_STACK_NAME}}}")),
             )
 
-    def sort_alb_ingress(self, stack_template):
+    def sort_alb_ingress(self, settings, stack_template):
         """
         Method to handle Ingress to ALB
         """
@@ -866,7 +867,7 @@ class Elbv2(XResource):
         self.ingress = Ingress(self.parameters["Ingress"], ports)
         if self.ingress and self.is_alb():
             self.ingress.set_aws_sources(
-                self.logical_name, GetAtt(self.lb_sg, "GroupId")
+                settings, self.logical_name, GetAtt(self.lb_sg, "GroupId")
             )
             self.ingress.set_ext_sources_ingress(
                 self.logical_name, GetAtt(self.lb_sg, "GroupId")
@@ -874,6 +875,27 @@ class Elbv2(XResource):
             self.ingress.associate_aws_igress_rules(stack_template)
             self.ingress.associate_ext_igress_rules(stack_template)
 
+    def define_override_subnets(self, subnets, settings):
+        """
+        Method to define the subnets overrides to use for the LB
+
+        :param subnets: The original subnets to replace
+        :param ecs_composex.common.settings.ComposeXSettings settings:
+        :return: the subnet name to use
+        :rtype: str
+        """
+
+        if isinstance(subnets, Ref):
+            subnets = subnets.data["Ref"]
+        if self.parameters and keyisset("Subnets", self.parameters):
+            if not self.parameters["Subnets"] in settings.subnets_mappings.keys():
+                raise KeyError(
+                    f"The subnets indicated for {self.name} is not valid. Valid ones are",
+                    settings.subnets_mappings.keys(),
+                )
+            subnets = self.parameters["Subnets"]
+        return subnets
+
     def set_eips(self, settings):
         """
 
@@ -881,33 +903,71 @@ class Elbv2(XResource):
         :return:
         """
         if self.is_nlb() and self.lb_is_public:
-            for public_az in settings.public_azs:
-                self.lb_eips.append(
-                    EIP(
-                        f"{self.logical_name}Eip{public_az.title().split('-')[-1]}",
-                        Domain="vpc",
+            if settings.create_vpc:
+                for public_az in settings.aws_azs:
+                    self.lb_eips.append(
+                        EIP(
+                            f"{self.logical_name}Eip{public_az['ZoneName'].title().split('-')[-1]}",
+                            Domain="vpc",
+                        )
+                    )
+            else:
+                subnets = self.define_override_subnets(PUBLIC_SUBNETS.title, settings)
+                for public_az in settings.subnets_mappings[subnets]["Azs"]:
+                    self.lb_eips.append(
+                        EIP(
+                            f"{self.logical_name}Eip{public_az.title().split('-')[-1]}",
+                            Domain="vpc",
+                        )
                     )
-                )
 
-    def set_subnets(self):
+    def set_subnets(self, settings):
+        """
+        Method to define which subnets to use for the
+        :param ecs_composex.common.settings.ComposeXSettings settings:
+        :return:
+        """
+        subnets = APP_SUBNETS.title
         if self.is_nlb() and self.lb_is_public:
-            return Ref(AWS_NO_VALUE)
-        elif self.is_alb() and self.lb_is_public:
-            return Ref(PUBLIC_SUBNETS)
-        elif not self.lb_is_public:
-            return Ref(APP_SUBNETS)
+            subnets = Ref(AWS_NO_VALUE)
+        elif (
+            not self.lb_is_public
+            and self.parameters
+            and keyisset("Subnets", self.parameters)
+        ):
+            override_name = self.define_override_subnets(subnets, settings)
+            if settings.create_vpc and override_name not in [
+                PUBLIC_SUBNETS.title,
+                APP_SUBNETS.title,
+            ]:
+                raise ValueError(
+                    "When Compose-X creates the VPC, the only subnets you can define to use are",
+                    [PUBLIC_SUBNETS.title, APP_SUBNETS.title],
+                )
+            elif (
+                not settings.create_vpc
+                and override_name in settings.subnets_mappings.keys()
+            ):
+                subnets = Ref(override_name)
+        else:
+            if self.is_alb() and self.lb_is_public:
+                subnets = Ref(PUBLIC_SUBNETS)
+            elif not self.lb_is_public:
+                subnets = Ref(APP_SUBNETS)
+        return subnets
 
     def set_subnet_mappings(self, settings):
         if not (self.is_nlb() and self.lb_is_public):
             return Ref(AWS_NO_VALUE)
-        if not self.lb_eips:
+        if not self.lb_eips and self.lb_is_public:
             self.set_eips(settings)
         mappings = []
+        subnets = self.define_override_subnets(PUBLIC_SUBNETS.title, settings)
         for count, eip in enumerate(self.lb_eips):
             mappings.append(
                 SubnetMapping(
                     AllocationId=GetAtt(eip, "AllocationId"),
-                    SubnetId=Select(count, Ref(PUBLIC_SUBNETS)),
+                    SubnetId=Select(count, Ref(subnets)),
                 )
             )
         return mappings
@@ -915,7 +975,9 @@ class Elbv2(XResource):
     def parse_attributes_settings(self):
         """
         Method to parse pre-defined settings for shortcuts
-        :return:
+
+        :return: the lb attributes mappings
+        :rtype: list
         """
         valid_settings = [
             ("timeout_seconds", int, handle_timeout_seconds, self.is_alb()),
@@ -937,16 +999,16 @@ class Elbv2(XResource):
         mappings = []
         for setting in valid_settings:
             if (
-                keypresent(setting[0], self.settings)
-                and isinstance(self.settings[setting[0]], setting[1])
+                keypresent(setting[0], self.parameters)
+                and isinstance(self.parameters[setting[0]], setting[1])
                 and setting[3]
             ):
                 if setting[2] and setting[3]:
-                    mappings.append(setting[2](self.settings[setting[0]]))
+                    mappings.append(setting[2](self.parameters[setting[0]]))
                 elif setting[3]:
                     mappings.append(
                         LoadBalancerAttributes(
-                            Key=setting[0], Value=str(self.settings[setting[0]])
+                            Key=setting[0], Value=str(self.parameters[setting[0]])
                         )
                     )
         return mappings
@@ -954,6 +1016,9 @@ class Elbv2(XResource):
     def set_lb_attributes(self):
         """
         Method to define the LB attributes
+
+        :return: List of LB Attributes
+        :rtype: list
         """
         attributes = []
         if keyisset("LoadBalancerAttributes", self.properties):
@@ -963,7 +1028,9 @@ class Elbv2(XResource):
                         Key=prop, Value=self.properties["LoadBalancerAttributes"][prop]
                     )
                 )
-        elif not keyisset("LoadBalancerAttributes", self.definition) and self.settings:
+        elif (
+            not keyisset("LoadBalancerAttributes", self.definition) and self.parameters
+        ):
             attributes = self.parse_attributes_settings()
         if attributes:
             return attributes
@@ -974,7 +1041,7 @@ class Elbv2(XResource):
         Function to parse the LB settings and properties and build the LB object
 
         :param ecs_composex.elbv2.elbv2_stack.Elbv2 self:
-        :return:
+        :param ecs_composex.common.settings.ComposeXSettings settings:
         """
         attrs = {
             "IpAddressType": "ipv4"
@@ -985,7 +1052,7 @@ class Elbv2(XResource):
             "SecurityGroups": [Ref(self.lb_sg)]
             if isinstance(self.lb_sg, SecurityGroup)
             else self.lb_sg,
-            "Subnets": self.set_subnets(),
+            "Subnets": self.set_subnets(settings),
             "SubnetMappings": self.set_subnet_mappings(settings),
             "LoadBalancerAttributes": self.set_lb_attributes(),
             "Tags": Tags(Name=Sub(f"${{{ROOT_STACK_NAME.title}}}{self.logical_name}")),
@@ -1037,12 +1104,11 @@ class XStack(ComposeXStack):
     """
 
     def __init__(self, title, settings, **kwargs):
-        set_resources(settings, Elbv2, RES_KEY)
-        resources = settings.compose_content[RES_KEY]
+        set_resources(settings, Elbv2, RES_KEY, MOD_KEY)
         new_resources = [
-            resources[res_name]
-            for res_name in resources
-            if not resources[res_name].lookup
+            lb
+            for lb in settings.compose_content[RES_KEY].values()
+            if not lb.lookup and not lb.use
         ]
         if not new_resources:
             self.is_void = True
@@ -1055,5 +1121,5 @@ class XStack(ComposeXStack):
         }
         for resource in new_resources:
             resource.set_lb_definition(settings)
-            resource.sort_alb_ingress(stack_template)
+            resource.sort_alb_ingress(settings, stack_template)
         super().__init__(title, stack_template, stack_parameters=lb_input, **kwargs)
