@@ -1,6 +1,6 @@
 ﻿#  -*- coding: utf-8 -*-
 #   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
+#   Copyright (C) 2020-2021  John Mille <john@compose-x.io>
 #  #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -24,7 +24,6 @@ from troposphere import (
     AWS_NO_VALUE,
     AWS_URL_SUFFIX,
 )
-from troposphere import Parameter
 
 from troposphere.events import (
     Target,
@@ -36,6 +35,7 @@ from troposphere.events import (
 from troposphere.iam import Role, Policy, PolicyType
 
 from ecs_composex.common import add_parameters, keyisset, LOG
+from ecs_composex.common.cfn_params import Parameter
 from ecs_composex.ecs.ecs_params import (
     CLUSTER_NAME,
     FARGATE_VERSION,
