@@ -1,6 +1,6 @@
 ﻿#  -*- coding: utf-8 -*-
 #   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
+#   Copyright (C) 2020-2021  John Mille <john@compose-x.io>
 #  #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -16,16 +16,17 @@
 #   along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from os import path
-from troposphere import Parameter
 from ecs_composex.ecs_composex import X_KEY
+from ecs_composex.common.cfn_params import Parameter
 
 
-RES_KEY = f"{X_KEY}{path.basename(path.dirname(path.abspath(__file__)))}"
+MOD_KEY = path.basename(path.dirname(path.abspath(__file__)))
+RES_KEY = f"{X_KEY}{MOD_KEY}"
 
 STREAM_ID_T = "StreamId"
 STREAM_ARN_T = "Arn"
 STREAM_KMS_KEY_ID_T = "KmsKeyId"
 
 STREAM_ID = Parameter(STREAM_ID_T, Type="String")
-STREAM_ARN = Parameter(STREAM_ARN_T, Type="String")
+STREAM_ARN = Parameter(STREAM_ARN_T, return_value="Arn", Type="String")
 STREAM_KMS_KEY_ID = Parameter(STREAM_KMS_KEY_ID_T, Type="String")
