@@ -1,6 +1,6 @@
 ﻿#  -*- coding: utf-8 -*-
 #   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
+#   Copyright (C) 2020-2021  John Mille <john@compose-x.io>
 #  #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -24,10 +24,10 @@ from ecs_composex.kinesis.kinesis_params import (
     STREAM_ID,
     STREAM_ARN,
     RES_KEY,
-    STREAM_KMS_KEY_ID,
+    MOD_KEY,
 )
-from ecs_composex.kinesis.kinesis_template import create_streams_template
 from ecs_composex.kinesis.kinesis_perms import ACCESS_TYPES
+from ecs_composex.kinesis.kinesis_template import create_streams_template
 
 
 class Stream(XResource):
@@ -37,21 +37,15 @@ class Stream(XResource):
 
     policies_scaffolds = ACCESS_TYPES
 
-    def __init__(self, name, definition, settings):
-        super().__init__(name, definition, settings)
-        self.arn_attr = STREAM_ARN
-        self.main_attr = STREAM_ID
-        self.kms_arn_attr = STREAM_KMS_KEY_ID
-
     def init_outputs(self):
         self.output_properties = {
-            STREAM_ARN.title: (
+            STREAM_ID: (self.logical_name, self.cfn_resource, Ref, None),
+            STREAM_ARN: (
                 f"{self.logical_name}{STREAM_ARN.title}",
                 self.cfn_resource,
                 GetAtt,
-                STREAM_ARN.title,
+                STREAM_ARN.return_value,
             ),
-            STREAM_ID.title: (self.logical_name, self.cfn_resource, Ref, None),
         }
 
 
@@ -61,14 +55,16 @@ class XStack(ComposeXStack):
     """
 
     def __init__(self, title, settings, **kwargs):
-        set_resources(settings, Stream, RES_KEY)
+        set_resources(settings, Stream, RES_KEY, MOD_KEY)
         new_resources = [
-            settings.compose_content[RES_KEY][stream_name]
-            for stream_name in settings.compose_content[RES_KEY]
-            if not settings.compose_content[RES_KEY][stream_name].lookup
+            stream
+            for stream in settings.compose_content[RES_KEY].values()
+            if not stream.lookup and not stream.use
         ]
         if new_resources:
             stack_template = create_streams_template(new_resources, settings)
             super().__init__(title, stack_template, **kwargs)
         else:
             self.is_void = True
+        for resource in settings.compose_content[RES_KEY].values():
+            resource.stack = self
