@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #  ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#  Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
+#  Copyright (C) 2020-2021  John Mille <john@compose-x.io>
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@ Main module template to generate the RDS Root template and all stacks according
 from troposphere import Output
 from troposphere import Ref, Join, GetAtt
 
-from ecs_composex.common import build_template, keyisset
+from ecs_composex.common import keyisset
 from ecs_composex.common.cfn_params import ROOT_STACK_NAME_T, ROOT_STACK_NAME
 from ecs_composex.common.stacks import ComposeXStack
 from ecs_composex.rds.rds_db_template import (
@@ -57,10 +57,9 @@ def add_db_stack(root_template, db, settings):
     """
     Function to add the DB stack to the root stack
 
-    :param root_template: root template to add the nested stack to
-    :type root_template: troposphere.Template
-    :param db: the database definition from the compose file
-    :type db: ecs_composex.common.compose_resources.Rds
+    :param troposphere.Template root_template: root template to add the nested stack to
+    :param ecs_composex.rds.rds_stack.Rds db: the database definition from the compose file
+    :param ecs_composex.common.settings.ComposeXSettings settings:
     """
     if db.properties:
         if not all(
@@ -119,15 +118,15 @@ def add_db_stack(root_template, db, settings):
     root_template.add_output(new_outputs)
 
 
-def generate_rds_templates(new_dbs, settings):
+def generate_rds_templates(root_tpl, new_dbs, settings):
     """
     Function to generate the RDS root template for all the DBs defined in the x-rds section of the compose file
 
+    :param troposphere.Template root_tpl:
     :param list new_dbs:
-    :return: rds_root_template, the RDS Root template with nested stacks
-    :rtype: troposphere.Template
+    :param ecs_composex.common.settings.ComposeXSettings settings:
+    :param ecs_composex.rds.rds_stack.XStack self_stack:
     """
-    root_tpl = build_template("RDS Root Template", [VPC_ID, STORAGE_SUBNETS])
     for db in new_dbs:
         add_db_stack(root_tpl, db, settings)
     return root_tpl
