@@ -1,6 +1,6 @@
 ﻿#  -*- coding: utf-8 -*-
 #   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
+#   Copyright (C) 2020-2021  John Mille <john@compose-x.io>
 #  #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@ from json import dumps
 from troposphere import FindInMap, Sub, Ref
 
 from ecs_composex.common import LOG, keyisset, add_parameters
+from ecs_composex.common.compose_resources import get_parameter_settings
 from ecs_composex.common.stacks import ComposeXStack
 from ecs_composex.kms.kms_perms import ACCESS_TYPES as KMS_ACCESS_TYPES
 from ecs_composex.resource_settings import (
@@ -31,8 +32,12 @@ from ecs_composex.resource_settings import (
     generate_resource_permissions,
     get_selected_services,
 )
-from ecs_composex.s3.s3_params import MOD_KEY
 from ecs_composex.s3.s3_aws import lookup_bucket_config
+from ecs_composex.s3.s3_params import (
+    MOD_KEY,
+    S3_BUCKET_NAME,
+    S3_BUCKET_ARN,
+)
 from ecs_composex.s3.s3_perms import ACCESS_TYPES
 
 
@@ -40,7 +45,7 @@ def assign_service_permissions_to_bucket(bucket, family, services, access, value
     bucket_key = "bucket"
     objects_key = "objects"
 
-    bucket.generate_resource_envvars(value)
+    bucket.generate_resource_envvars()
 
     if keyisset(bucket_key, access):
         bucket_perms = generate_resource_permissions(
@@ -72,35 +77,42 @@ def assign_new_bucket_to_services(bucket, res_root_stack, nested=False):
     """
     bucket_key = "bucket"
     objects_key = "objects"
-    access = {objects_key: "RW", bucket_key: "ListOnly"}
-    bucket.set_ref_resource_value(res_root_stack.title)
-    bucket.set_resource_arn_parameter()
-    bucket.set_resource_arn(res_root_stack.title)
+    attributes_settings = [
+        get_parameter_settings(bucket, attribute)
+        for attribute in bucket.output_properties
+    ]
+    params_to_add = []
+    params_values = {}
+    for setting in attributes_settings:
+        params_to_add.append(setting[1])
+        params_values[setting[0]] = setting[2]
     for target in bucket.families_targets:
         select_services = get_selected_services(bucket, target)
+        access = {objects_key: "RW", bucket_key: "ListOnly"}
         if select_services:
-            if not isinstance(target[3], str):
+            if not keyisset("access", target[3]):
                 LOG.warning(
-                    f"No permissions associated for {bucket.name} to {target[0].name}. Setting default."
+                    f"No permissions associated for {target[0].name}. Setting default."
+                )
+            elif isinstance(target[3], str):
+                LOG.warning(
+                    f"Permissions for bucket must be a map with {bucket_key} and {objects_key}"
+                    " defined. Setting to default"
                 )
             else:
                 access = target[3]
             add_parameters(
-                target[0].template, [bucket.ref_parameter, bucket.arn_parameter]
-            )
-            target[0].stack.Parameters.update(
-                {
-                    bucket.ref_parameter.title: bucket.ref_value,
-                    bucket.arn_parameter.title: bucket.arn_value,
-                }
+                target[0].template,
+                params_to_add,
             )
+            target[0].stack.Parameters.update(params_values)
             assign_service_permissions_to_bucket(
                 bucket,
                 target[0],
                 select_services,
                 access,
-                value=Ref(bucket.ref_parameter),
-                arn=Ref(bucket.arn_parameter),
+                value=Ref(bucket.attributes_outputs[S3_BUCKET_NAME]["ImportParameter"]),
+                arn=Ref(bucket.attributes_outputs[S3_BUCKET_ARN]["ImportParameter"]),
             )
             if res_root_stack.title not in target[0].stack.DependsOn:
                 target[0].stack.DependsOn.append(res_root_stack.title)
@@ -187,15 +199,18 @@ def define_bucket_mappings(buckets_mappings, buckets, settings):
             )
 
 
-def define_lookup_buckets_access(bucket, target, services, access):
+def define_lookup_buckets_access(bucket, target, services):
     """
     Function to create the IAM policy for the service access to bucket
 
     :param bucket:
+    :param target:
+    :param services:
     :return:
     """
     bucket_key = "bucket"
     objects_key = "objects"
+    access = {objects_key: "RW", bucket_key: "ListOnly"}
     if isinstance(target[3], str):
         LOG.warning(
             "For s3 buckets, you should define a dict for access, with bucket and/or object policies separate."
@@ -209,9 +224,7 @@ def define_lookup_buckets_access(bucket, target, services, access):
         not keyisset(objects_key, target[3]) or not keyisset(bucket_key, target[3])
     ):
         raise KeyError("You must define at least bucket or object access")
-    bucket.generate_resource_envvars(
-        FindInMap("s3", bucket.logical_name, bucket.logical_name)
-    )
+    bucket.generate_resource_envvars()
     if keyisset(bucket_key, access):
         bucket_perms = generate_resource_permissions(
             f"BucketAccess{bucket.logical_name}",
@@ -244,19 +257,10 @@ def assign_lookup_buckets(bucket, mappings):
     if not keyisset(bucket.logical_name, mappings):
         LOG.warning(f"Bucket {bucket.logical_name} was not found in mappings. Skipping")
         return
-    bucket_key = "bucket"
-    objects_key = "objects"
-    access = {objects_key: "RW", bucket_key: "ListOnly"}
     for target in bucket.families_targets:
         select_services = get_selected_services(bucket, target)
         if select_services:
             target[0].template.add_mapping("s3", mappings)
-            if not keyisset("access", target[3]) or isinstance(target[3], str):
-                LOG.warning(
-                    f"No permissions associated for {target[0].name}. Setting default."
-                )
-            else:
-                access = target[3]
             if keyisset("KmsKey", mappings[bucket.logical_name]):
                 kms_perms = generate_resource_permissions(
                     f"{bucket.logical_name}KmsKey",
@@ -270,7 +274,7 @@ def assign_lookup_buckets(bucket, mappings):
                     "EncryptDecrypt",
                     select_services,
                 )
-            define_lookup_buckets_access(bucket, target, select_services, access)
+            define_lookup_buckets_access(bucket, target, select_services)
 
 
 def s3_to_ecs(xresources, services_stack, res_root_stack, settings):
