@@ -1,6 +1,6 @@
 ﻿#  -*- coding: utf-8 -*-
 #   ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#   Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
+#   Copyright (C) 2020-2021  John Mille <john@compose-x.io>
 #  #
 #   This program is free software: you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -17,27 +17,33 @@
 
 from troposphere import GetAtt, Ref
 
-from ecs_composex.common import keyisset, LOG
+from ecs_composex.common import keyisset, build_template
 from ecs_composex.common.compose_resources import XResource
 from ecs_composex.common.stacks import ComposeXStack
-from ecs_composex.sns.sns_params import RES_KEY, TOPIC_NAME, TOPIC_ARN, TOPIC_KMS_KEY
+from ecs_composex.sns.sns_params import (
+    RES_KEY,
+    TOPIC_NAME,
+    TOPIC_ARN,
+    MOD_KEY,
+)
 from ecs_composex.sns.sns_perms import ACCESS_TYPES
 from ecs_composex.sns.sns_templates import generate_sns_templates
+from ecs_composex.sns.sns_aws import lookup_topic_config
 from ecs_composex.sqs.sqs_params import RES_KEY as SQS_KEY
 
 
-def create_sns_template(settings):
-    """
-    Function to create SNS templates as part of ECS ComposeX.
-
-    :param settings:
-    :type settings: ecs_composex.common.settings.ComposeXSettings
-    :return: SNS root template
-    :rtype: troposphere.Template
-    """
-    if keyisset(RES_KEY, settings.compose_content):
-        LOG.debug(f"Processing {RES_KEY} package")
-        return generate_sns_templates(settings)
+def create_sns_mappings(resources, settings):
+    if not keyisset(RES_KEY, settings.mappings):
+        mappings = {}
+        settings.mappings[RES_KEY] = mappings
+    else:
+        mappings = settings.mappings[RES_KEY]
+    for resource in resources:
+        resource_config = lookup_topic_config(
+            resource.logical_name, resource.lookup, settings.session
+        )
+        if resource_config:
+            mappings.update({resource.logical_name: resource_config})
 
 
 class Topic(XResource):
@@ -48,25 +54,15 @@ class Topic(XResource):
     policies_scaffolds = ACCESS_TYPES
     keyword = "Topics"
 
-    def __init__(self, name, definition, settings):
-        super().__init__(name, definition, settings)
-        self.arn_attr = TOPIC_ARN
-        self.main_attr = TOPIC_NAME
-        self.kms_attr = TOPIC_KMS_KEY
-        self.arn_attr_value = self.arn_attr
-        self.main_attr_value = self.main_attr
-        self.kms_attr_value = self.kms_attr
-
     def init_outputs(self):
         self.output_properties = {
-            TOPIC_ARN.title: (self.logical_name, self.cfn_resource, Ref, None),
-            TOPIC_NAME.title: (
+            TOPIC_ARN: (self.logical_name, self.cfn_resource, Ref, None),
+            TOPIC_NAME: (
                 f"{self.logical_name}{TOPIC_NAME.title}",
                 self.cfn_resource,
                 GetAtt,
-                TOPIC_NAME.title,
+                TOPIC_NAME.return_value,
             ),
-            self.arn_attr.title: (self.logical_name, self.cfn_resource, Ref, None),
         }
 
 
@@ -84,30 +80,61 @@ class XStack(ComposeXStack):
     """
 
     def __init__(self, title, settings, **kwargs):
+        topics = []
+        subscriptions = []
         if keyisset(Topic.keyword, settings.compose_content[RES_KEY]):
             for resource_name in settings.compose_content[RES_KEY][Topic.keyword]:
-                settings.compose_content[RES_KEY][Topic.keyword][resource_name] = Topic(
+                topic = Topic(
                     resource_name,
                     settings.compose_content[RES_KEY][Topic.keyword][resource_name],
+                    MOD_KEY,
                     settings,
                 )
+                settings.compose_content[RES_KEY][Topic.keyword][resource_name] = topic
+                topics.append(topic)
 
         if keyisset(Subscription.keyword, settings.compose_content[RES_KEY]):
             for resource_name in settings.compose_content[RES_KEY][
                 Subscription.keyword
             ]:
-                settings.compose_content[RES_KEY][Subscription.keyword][
-                    resource_name
-                ] = Topic(
+                subscription = Subscription(
                     resource_name,
                     settings.compose_content[RES_KEY][Subscription.keyword][
                         resource_name
                     ],
+                    MOD_KEY,
                     settings,
                 )
+                settings.compose_content[RES_KEY][Subscription.keyword][
+                    resource_name
+                ] = subscription
+                subscriptions.append(subscription)
 
-        template = create_sns_template(settings)
-        super().__init__(title, stack_template=template, **kwargs)
+        new_topics = [topic for topic in topics if not topic.lookup and not topic.use]
+        new_subscriptions = [
+            subscription
+            for subscription in subscriptions
+            if not subscription.lookup and not subscription.use
+        ]
+        if not new_topics and not new_subscriptions:
+            self.is_void = True
+        else:
+            template = build_template(
+                "Root template for SNS generated by ECS Compose-X"
+            )
+            generate_sns_templates(
+                settings, new_topics, new_subscriptions, self, template
+            )
+            super().__init__(title, stack_template=template, **kwargs)
+        for topic in topics:
+            topic.stack = self
+        for subscription in subscriptions:
+            subscription.stack = self
+        lookup_topics = [
+            topic for topic in topics if topic.lookup and not topic.properties
+        ]
+        if lookup_topics:
+            create_sns_mappings(lookup_topics, settings)
 
     def handle_sqs(self, root_template, sqs_root_stack):
         """
