@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #  ECS ComposeX <https://github.com/lambda-my-aws/ecs_composex>
-#  Copyright (C) 2020-2021  John Mille <john@lambda-my-aws.io>
+#  Copyright (C) 2020-2021  John Mille <john@compose-x.io>
 #
 #  This program is free software: you can redistribute it and/or modify
 #  it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
 Parameters related to the VPC settings. Used by ecs_composex.vpc and others
 """
 
-from troposphere import Parameter
+from ecs_composex.common.cfn_params import Parameter
 
 VPC_TYPE = "AWS::EC2::VPC::Id"
 AMI_TYPE = "AWS::EC2::Image::Id"
